@@ -6,12 +6,15 @@ from credsweeper.file_handler import ContentProvider, ByteContentProvider, DiffC
     DataContentProvider, \
     TextContentProvider
 from credsweeper.ml_model.ml_validator import MlValidator
+from credsweeper.validations.apply_validation import ApplyValidation
 
 os.environ["TF_CPP_MIN_LOG_LEVEL"] = "2"
 
 __all__ = [
+    'ApplyValidation',  #
     'ByteContentProvider',  #
     'ContentProvider',  #
+    'CredSweeper',  #
     'DataContentProvider',  #
     'DiffContentProvider',  #
     'MlValidator',  #
@@ -21,4 +24,4 @@ __all__ = [
     '__version__'
 ]
 
-__version__ = "1.4.1"
+__version__ = "1.4.2"
