@@ -1,30 +1,32 @@
-from typing import List, Optional, Union
+import gzip
 import io
 import itertools
-import json
+import logging
 import multiprocessing
 import os
 import signal
 import sys
 import zipfile
+from typing import List, Optional, Union
+
 import pandas as pd
 
-from credsweeper.common.constants import KeyValidationOption, ThresholdPreset, DEFAULT_ENCODING, \
-    RECURSIVE_SCAN_LIMITATION
+from credsweeper.common.constants import KeyValidationOption, ThresholdPreset, RECURSIVE_SCAN_LIMITATION
 from credsweeper.config import Config
 from credsweeper.credentials import Candidate, CredentialManager
+from credsweeper.file_handler.byte_content_provider import ByteContentProvider
 from credsweeper.file_handler.content_provider import ContentProvider
-from credsweeper.file_handler.file_path_extractor import FilePathExtractor
-from credsweeper.file_handler.files_provider import FilesProvider
 from credsweeper.file_handler.data_content_provider import DataContentProvider
 from credsweeper.file_handler.diff_content_provider import DiffContentProvider
-from credsweeper.file_handler.byte_content_provider import ByteContentProvider
+from credsweeper.file_handler.file_path_extractor import FilePathExtractor
+from credsweeper.file_handler.files_provider import FilesProvider
 from credsweeper.file_handler.text_content_provider import TextContentProvider
-from credsweeper.logger.logger import logging
 from credsweeper.scanner import Scanner
 from credsweeper.utils import Util
 from credsweeper.validations.apply_validation import ApplyValidation
 
+logger = logging.getLogger(__name__)
+
 
 class CredSweeper:
     """Advanced credential analyzer base class.
@@ -72,8 +74,7 @@ class CredSweeper:
         """
         self.pool_count: int = int(pool_count) if int(pool_count) > 1 else 1
         dir_path = os.path.dirname(os.path.realpath(__file__))
-        with open(os.path.join(dir_path, "secret", "config.json"), "r", encoding=DEFAULT_ENCODING) as conf_file:
-            config_dict = json.load(conf_file)
+        config_dict = Util.json_load(os.path.join(dir_path, "secret", "config.json"))
 
         config_dict["validation"] = {}
         config_dict["validation"]["api_validation"] = api_validation
@@ -145,7 +146,7 @@ class CredSweeper:
 
     # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 
-    def run(self, content_provider: FilesProvider) -> None:
+    def run(self, content_provider: FilesProvider) -> int:
         """Run an analysis of 'content_provider' object.
 
         Args:
@@ -155,11 +156,13 @@ class CredSweeper:
         _empty_list: List[TextContentProvider] = []
         file_extractors: Union[List[DiffContentProvider], List[TextContentProvider]] = \
             content_provider.get_scannable_files(self.config) if content_provider else _empty_list
-        logging.info("Start Scanner")
+        logger.info("Start Scanner")
         self.scan(file_extractors)
         self.post_processing()
         self.export_results()
 
+        return len(self.credential_manager.get_credentials())
+
     # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 
     def scan(self, content_providers: Union[List[DiffContentProvider], List[TextContentProvider]]) -> None:
@@ -176,7 +179,7 @@ class CredSweeper:
 
     # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 
-    def __single_job_scan(self, content_providers: Union[List[DiffContentProvider], List[TextContentProvider]]):
+    def __single_job_scan(self, content_providers: Union[List[DiffContentProvider], List[TextContentProvider]]) -> None:
         """Performs scan in main thread"""
         all_cred: List[Candidate] = []
         for i in content_providers:
@@ -185,7 +188,7 @@ class CredSweeper:
         if self.config.api_validation:
             api_validation = ApplyValidation()
             for cred in all_cred:
-                logging.info("Run API Validation")
+                logger.info("Run API Validation")
                 cred.api_validation = api_validation.validate(cred)
                 self.credential_manager.add_credential(cred)
         else:
@@ -193,7 +196,7 @@ class CredSweeper:
 
     # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 
-    def __multi_jobs_scan(self, content_providers: Union[List[DiffContentProvider], List[TextContentProvider]]):
+    def __multi_jobs_scan(self, content_providers: Union[List[DiffContentProvider], List[TextContentProvider]]) -> None:
         """Performs scan with multiple jobs"""
         with multiprocessing.get_context("spawn").Pool(self.pool_count, initializer=self.pool_initializer) as pool:
             try:
@@ -204,7 +207,7 @@ class CredSweeper:
                 for cred in scan_results:
                     self.credential_manager.add_credential(cred)
                 if self.config.api_validation:
-                    logging.info("Run API Validation")
+                    logger.info("Run API Validation")
                     api_validation = ApplyValidation()
                     api_validation.validate_credentials(pool, self.credential_manager)
             except KeyboardInterrupt:
@@ -225,7 +228,7 @@ class CredSweeper:
 
         """
         candidates: List[Candidate] = []
-        logging.debug(f"Start scan file: {content_provider.file_path}")
+        logger.debug("Start scan file: %s", content_provider.file_path)
 
         if FilePathExtractor.is_find_by_ext_file(self.config, content_provider.file_path):
             # Skip the file scanning and create fake candidate because the extension is suspicious
@@ -257,11 +260,11 @@ class CredSweeper:
                 recursive_limit_size: maximal bytes of opened files to prevent recursive zip-bomb attack
         """
         candidates: List[Candidate] = []
-        logging.debug(f"Start scan data: {data_provider.file_path} {len(data_provider.data)} bytes")
+        logger.debug("Start scan data: %s %d bytes", data_provider.file_path, len(data_provider.data))
 
         if 0 > depth:
             # break recursion if maximal depth is reached
-            logging.debug(f"bottom reached {data_provider.file_path} recursive_limit_size:{recursive_limit_size}")
+            logger.debug("bottom reached %s recursive_limit_size:%d", data_provider.file_path, recursive_limit_size)
             return candidates
 
         depth -= 1
@@ -282,7 +285,7 @@ class CredSweeper:
                         if FilePathExtractor.check_exclude_file(self.config, file_path):
                             continue
                         if 0 > recursive_limit_size - zfl.file_size:
-                            logging.error(
+                            logger.error(
                                 f"{file_path}: size {zfl.file_size} is over limit {recursive_limit_size} depth:{depth}")
                             continue
                         with zf.open(zfl) as f:
@@ -291,9 +294,19 @@ class CredSweeper:
                             new_limit = recursive_limit_size - len(zip_content_provider.data)
                             candidates.extend(self.data_scan(zip_content_provider, depth, new_limit))
 
-            except (zipfile.LargeZipFile, zipfile.BadZipFile, RuntimeError) as zip_exc:
-                # RuntimeError is possible when zip file is encrypted
-                logging.error(f"{data_provider.file_path}:{zip_exc}")
+            except Exception as zip_exc:
+                # too many exception types might be produced with broken zip
+                logger.error(f"{data_provider.file_path}:{zip_exc}")
+
+        elif Util.is_gzip(data_provider.data):
+            try:
+                with gzip.open(io.BytesIO(data_provider.data)) as f:
+                    gzip_content_provider = DataContentProvider(data=f.read(), file_path=data_provider.file_path)
+                    new_limit = recursive_limit_size - len(gzip_content_provider.data)
+                    candidates.extend(self.data_scan(gzip_content_provider, depth, new_limit))
+            except Exception as gzip_exc:
+                logger.error(f"{data_provider.file_path}:{gzip_exc}")
+
         else:
             # finally try scan the date via byte content provider
             byte_content_provider = ByteContentProvider(content=data_provider.data, file_path=data_provider.file_path)
@@ -308,7 +321,7 @@ class CredSweeper:
     def post_processing(self) -> None:
         """Machine learning validation for received credential candidates."""
         if self._use_ml_validation():
-            logging.info("Run ML Validation")
+            logger.info("Run ML Validation")
             new_cred_list = []
             cred_groups = self.credential_manager.group_credentials()
             ml_cred_groups = []
@@ -340,10 +353,8 @@ class CredSweeper:
 
         if self.json_filename:
             is_exported = True
-            with open(self.json_filename, "w", encoding=DEFAULT_ENCODING) as result_file:
-                json.dump([credential.to_json() for credential in self.credential_manager.get_credentials()],
-                          result_file,
-                          indent=4)
+            Util.json_dump([credential.to_json() for credential in self.credential_manager.get_credentials()],
+                           file_path=self.json_filename)
 
         if self.xlsx_filename:
             is_exported = True
