@@ -96,7 +96,7 @@ MAX_LINE_LENGTH = 1500
 
 DEFAULT_ENCODING = "utf8"
 
-AVAILABLE_ENCODINGS = ("utf8", "utf16", "latin_1")
+AVAILABLE_ENCODINGS = (DEFAULT_ENCODING, "utf16", "latin_1")
 
 # to limit memory usage in case of recursive scan
 RECURSIVE_SCAN_LIMITATION = 1 << 30
