@@ -5,6 +5,8 @@ import yaml
 
 from credsweeper.common.constants import DEFAULT_ENCODING
 
+logger = logging.getLogger(__name__)
+
 CONFIG_PATH = Path(__file__).resolve().parent.parent.joinpath("secret")
 
 
@@ -17,7 +19,7 @@ class ConfigManager:
             with open(file_path, "r", encoding=DEFAULT_ENCODING) as f:
                 conf = yaml.load(f, Loader=yaml.FullLoader)
         except (IOError, OSError):
-            logging.error(f"Failed to read {file_path}")
+            logger.error(f"Failed to read {file_path}")
             raise
 
         return conf
