@@ -1,9 +1,12 @@
+import logging
 from typing import Dict, List, Optional
 
 from credsweeper.file_handler.analysis_target import AnalysisTarget
 from credsweeper.file_handler.content_provider import ContentProvider
 from credsweeper.utils import Util
 
+logger = logging.getLogger(__name__)
+
 
 class TextContentProvider(ContentProvider):
     """Provide access to analysis targets for full-text file scanning.
@@ -23,5 +26,13 @@ class TextContentProvider(ContentProvider):
             list of analysis targets based on every row in file
 
         """
-        lines = Util.read_file(self.file_path)
-        return self.lines_to_targets(lines)
+        lines: Optional[List[str]] = None
+        line_nums: List[int] = []
+
+        if Util.get_extension(self.file_path) == ".xml":
+            lines, line_nums = Util.get_xml_data(self.file_path)
+
+        if lines is None:
+            lines = Util.read_file(self.file_path)
+
+        return self.lines_to_targets(lines, line_nums)
