@@ -3,15 +3,17 @@ from credsweeper.filters import Filter
 
 
 class ValueDictionaryValueLengthCheck(Filter):
-    """Check that candidate length is between 5 and 30"""
+    """Check that candidate length is between 5 and 30."""
+
     def run(self, line_data: LineData) -> bool:
-        """Run filter checks on received credential candidate data 'line_data'
+        """Run filter checks on received credential candidate data 'line_data'.
 
         Args:
-            line_data: LineData object, credential candidate data
+            line_data: credential candidate data
 
         Return:
-            boolean variable. True, if need to filter candidate and False if left
+            True, if need to filter candidate and False if left
+
         """
         if line_data.value is None:
             return True
