@@ -6,20 +6,22 @@ from credsweeper.utils import Util
 
 
 class ValueFirstWordCheck(Filter):
-    """Check that secret doesn't starts with special character"""
+    """Check that secret doesn't starts with special character."""
+
     NOT_ALLOWED = [
         "\\=", "\\{", "\\)", "\\<", "\\>", "\\#", "\\:", "\\\\", "\\/\\/", "\\_", "\\\\[u]", "\\/\\*", "\\%[deflspuvxz]"
     ]
     NOT_ALLOWED_PATTERN = regex.compile(f"^{Util.get_regex_combine_or(NOT_ALLOWED)}", flags=regex.IGNORECASE)
 
     def run(self, line_data: LineData) -> bool:
-        """Run filter checks on received credential candidate data 'line_data'
+        """Run filter checks on received credential candidate data 'line_data'.
 
         Args:
-            line_data: LineData object, credential candidate data
+            line_data: credential candidate data
 
         Return:
-            boolean variable. True, if need to filter candidate and False if left
+            True, if need to filter candidate and False if left
+
         """
         if line_data.value is None:
             return True
