@@ -1,14 +1,20 @@
+from dataclasses import dataclass
+from typing import Dict, List, Tuple, Optional, Any
+
+import json
 import logging
 import math
 import os
-from dataclasses import dataclass
-from typing import Dict, List, Tuple, Optional
+import whatthepatch
+
+from lxml import etree
+from regex import regex
 from typing_extensions import TypedDict
 
-import whatthepatch
-from regex import regex
+from credsweeper.common.constants import Chars, DiffRowType, KeywordPattern, Separator, AVAILABLE_ENCODINGS, \
+    DEFAULT_ENCODING
 
-from credsweeper.common.constants import Chars, DiffRowType, KeywordPattern, Separator, AVAILABLE_ENCODINGS
+logger = logging.getLogger(__name__)
 
 DiffDict = TypedDict(
     "DiffDict",
@@ -111,9 +117,9 @@ class Util:
                     file_data = file.read().split("\n")
                 break
             except UnicodeError:
-                logging.info(f"UnicodeError: Can't read content from \"{path}\" as {encoding}.")
+                logger.info(f"UnicodeError: Can't read content from \"{path}\" as {encoding}.")
             except Exception as exc:
-                logging.error(f"Unexpected Error: Can't read \"{path}\" as {encoding}. Error message: {exc}")
+                logger.error(f"Unexpected Error: Can't read \"{path}\" as {encoding}. Error message: {exc}")
         return file_data
 
     @staticmethod
@@ -142,9 +148,9 @@ class Util:
                 lines = text.replace('\r\n', '\n').replace('\r', '\n').split("\n")
                 break
             except UnicodeError:
-                logging.info(f"UnicodeError: Can't decode content as {encoding}.")
+                logger.info(f"UnicodeError: Can't decode content as {encoding}.")
             except Exception as exc:
-                logging.error(f"Unexpected Error: Can't read content as {encoding}. Error message: {exc}")
+                logger.error(f"Unexpected Error: Can't read content as {encoding}. Error message: {exc}")
         return lines
 
     @staticmethod
@@ -175,7 +181,7 @@ class Util:
         added_files, deleted_files = {}, {}
         for patch in patches:
             if patch.changes is None:
-                logging.warning(f"Patch '{str(patch.header)}' cannot be scanned")
+                logger.warning(f"Patch '{str(patch.header)}' cannot be scanned")
                 continue
             changes = []
             for change in patch.changes:
@@ -188,7 +194,7 @@ class Util:
         elif change_type == "deleted":
             return deleted_files
         else:
-            logging.error(f"Change type should be one of: 'added', 'deleted'; but received {change_type}")
+            logger.error(f"Change type should be one of: 'added', 'deleted'; but received {change_type}")
         return {}
 
     @staticmethod
@@ -236,6 +242,14 @@ class Util:
                     return False
         return False
 
+    @staticmethod
+    def is_gzip(data: bytes) -> bool:
+        """According https://www.rfc-editor.org/rfc/rfc1952"""
+        if isinstance(data, bytes) and 3 <= len(data):
+            if 0x1F == data[0] and 0x8B == data[1] and 0x08 == data[2]:
+                return True
+        return False
+
     @staticmethod
     def read_data(path: str) -> Optional[bytes]:
         """Read the file bytes as is.
@@ -255,5 +269,72 @@ class Util:
             with open(path, "rb") as file:
                 return file.read()
         except Exception as exc:
-            logging.error(f"Unexpected Error: Can not read '{path}'. Error message: '{exc}'")
+            logger.error(f"Unexpected Error: Can not read '{path}'. Error message: '{exc}'")
         return None
+
+    @staticmethod
+    def get_xml_data(file_path: str) -> Tuple[Optional[List[str]], Optional[List[int]]]:
+        """Read xml data and return List of str.
+
+        Try to read the xml data and return formatted string.
+
+        Args:
+            file_path: path of xml file
+
+        Return:
+            List of formatted string(f"{root.tag} : {root.text}")
+
+        """
+        lines = []
+        line_nums = []
+        try:
+            with open(file_path, "r") as f:
+                xml_lines = f.readlines()
+            tree = etree.fromstringlist(xml_lines)
+            for element in tree.iter():
+                tag = Util._extract_element_data(element, "tag")
+                text = Util._extract_element_data(element, "text")
+                lines.append(f"{tag} : {text}")
+                line_nums.append(element.sourceline)
+        except Exception as exc:
+            logger.error(f"Cannot parse '{file_path}' to xml {exc}")
+            return None, None
+        return lines, line_nums
+
+    @staticmethod
+    def _extract_element_data(element, attr) -> str:
+        """Extract xml element data to string.
+
+        Try to extract the xml data and strip() the string.
+
+        Args:
+            element: xml element
+            attr: attribute name
+
+        Return:
+            String xml data with strip()
+
+        """
+        element_attr: Any = getattr(element, attr)
+        if element_attr is None or not isinstance(element_attr, str):
+            return ""
+        return str(element_attr).strip()
+
+    @staticmethod
+    def json_load(file_path: str, encoding=DEFAULT_ENCODING) -> Any:
+        """Load dictionary from json file"""
+        try:
+            with open(file_path, "r", encoding=encoding) as f:
+                return json.load(f)
+        except Exception as exc:
+            logging.error(f"Failed to read: {file_path} {exc}")
+        return None
+
+    @staticmethod
+    def json_dump(obj: Any, file_path: str, encoding=DEFAULT_ENCODING, indent=4) -> None:
+        """Write dictionary to json file"""
+        try:
+            with open(file_path, "w", encoding=encoding) as f:
+                json.dump(obj, f, indent=indent)
+        except Exception as exc:
+            logging.error(f"Failed to write: {file_path} {exc}")
